@@ -3,7 +3,8 @@ import shutil
 from io import StringIO
 from typing import Dict, List, Optional, Set, Tuple
 
-from pygitguardian.models import Match, PolicyBreak
+from pygitguardian.client import VERSIONS
+from pygitguardian.models import HealthCheckResponse, Match, PolicyBreak
 
 from ggshield.text_utils import STYLE, Line, format_text, pluralize
 
@@ -282,6 +283,10 @@ def format_detector(match_type: str, index_start: int, index_end: int) -> str:
     return " " * index_start + format_text(display, STYLE["detector"]) + "\n"
 
 
+def secrets_engine_version() -> str:
+    return f"\nsecrets-engine-version: {VERSIONS.secrets_engine_version}"
+
+
 def file_info(filename: str, nb_secrets: int) -> str:
     """Return the formatted file info (number of secrets + filename)."""
     return "\n{} {} {} been found in file {}\n".format(
@@ -340,3 +345,13 @@ def format_quota_color(remaining: int, limit: int) -> str:
         color = "green"
 
     return format_text(str(remaining), {"fg": color})
+
+
+def format_healthcheck_status(health_check: HealthCheckResponse) -> str:
+    (color, status) = (
+        ("red", f"unhealthy ({health_check.detail})")
+        if health_check.status_code != 200
+        else ("green", "healthy")
+    )
+
+    return format_text(status, {"fg": color})
