@@ -8,7 +8,7 @@ from ggshield.git_shell import git_ls, is_git_dir
 
 from .config import MAX_FILE_SIZE
 from .filter import path_filter_set
-from .scannable import File, Files
+from .scan import File, Files
 
 
 BINARY_FILE_EXTENSIONS = (".tar", ".xz", ".gz")
@@ -40,7 +40,7 @@ def get_files_from_paths(
     size = len(files)
     if size > 1 and not yes:
         click.confirm(
-            f"{size} files will be scanned. Do you want to continue?", abort=True,
+            f"{size} files will be scanned. Do you want to continue?", abort=True
         )
 
     return Files(files)
@@ -81,7 +81,7 @@ def get_filepaths(
 def generate_files_from_paths(paths: Iterable[str], verbose: bool) -> Iterable[File]:
     """Generate a list of scannable files from a list of filepaths."""
     for path in paths:
-        if os.path.isdir(path):
+        if os.path.isdir(path) or not os.path.exists(path):
             continue
 
         file_size = os.path.getsize(path)
@@ -97,8 +97,6 @@ def generate_files_from_paths(paths: Iterable[str], verbose: bool) -> Iterable[F
             try:
                 content = file.read()
                 if content:
-                    yield File(
-                        content, file.name, file_size,
-                    )
+                    yield File(content, file.name, file_size)
             except UnicodeDecodeError:
                 pass
