@@ -1,10 +1,12 @@
+from .docker import get_files_from_docker_archive
 from .scannable import Commit, File, Files, Result, ScanCollection
 
 
 __all__ = [
+    "Commit",
     "File",
     "Files",
-    "Commit",
     "Result",
     "ScanCollection",
+    "get_files_from_docker_archive",
 ]
